function [ lat,lon,h ] = ECEF2geodv( a,b,X,Y,Z )
%Denne funksjonen regner om ECEF-koordinater til geodetiske koordinater
%   Vermeilles metode

e_squared = ((a^2)-(b^2)) / (a^2);
test1 = sqrt(X^2 + Y^2 + Z^2);
test2 = (a*e_squared)/sqrt(1-e_squared);

if test1 > test2 %vil i praksis alltid vre ok, med mindre det er feil i variable
    p = (X^2 + Y^2)/(a^2);
    q = ((1 - e_squared)/(a^2)) * Z^2;
    r = (p + q - (e_squared^2))/6;
    s = (e_squared^2) * ((p*q)/(4*(r^3)));
    t = (1 + s + sqrt(s*(2 + s)))^(1/3);
    u = r * (1 + t + (1/t));
    v = sqrt((u^2) + (e_squared^2)*q);
    w = e_squared * ((u + v - q) / (2 * v));
    k = sqrt(u + v  + w^2) - w;
    D = (k * sqrt(X^2 + Y^2)) / (k + e_squared);
    h = ((k + e_squared - 1)* sqrt((D^2) + (Z^2))) / k;
    lat = 2 * atan(Z/(D + sqrt(D^2 + Z^2)));
    lat = rad2deg(lat);
    
    if Y >= 0
        lon = (pi/2) - 2 * atan(X / (sqrt(X^2 + Y^2) + Y));
    elseif Y < 0
        lon = -(pi/2) + 2 * atan(X / (sqrt(X^2 + Y^2) - Y)); 
    end
    lon = rad2deg(lon);
else
    error('Illegal input in ECEF2geodv')
end
 
end

