function [ UTM_N,UTM_E ] = calculate_LatLon2UTM( B,L )
%Beregner fra geodetiske koordinater til UTM
%gjr om lengde og bredde til radianer igjen:
B2 = deg2rad(B);
L2 = deg2rad(L);

%UTM-ellipsoiden:
a = 6378137;
b = 6356752.3142;

%Utregning av bredde- og lengdekoordinatene:
L_0 = 9; %sentralmeridianen i grader
L_0 = deg2rad(L_0); %i radianer

%Koeffisienter:
alfa = 6367449.1458; %avhenger av ellipsekonstantene
n = (a-b)/(a+b);
beta = -((3/2)*n) + ((9/16)*(n^3)) - ((3/32)*(n^5));
gamma = ((15/16)*(n^2)) - ((15/32)*(n^4));
delta_spherical = -((35/48)*(n^3)) + ((105/256)*(n^5));
epsilon = ((315/512)*(n^4));

t = tan(B2);
eta = (cos(B2)*sqrt((a^2)-(b^2)))/b;

%trekker fra sentralmeridianen:
l = L2 - L_0; 

%arc length of meridian:
B_arc = alfa * (B2+(beta*sin(2*B2))+(gamma*sin(4*B2))+(delta_spherical*sin(6*B2))+(epsilon*sin(8*B2))); 

%radii of curvature:
N = (a^2)/(sqrt(((a^2)*(cos(B2)^2))+((b^2)*(sin(B2)^2)))); 

%Koeffisienter i den endelige formelen:
a1 = N*cos(B2);
a2 = (t*N*(cos(B2)^2))/2;
a3 = (N*(cos(B2)^3)*(1-(t^2)+(eta^2)))/6;
a4 = (t*N*(cos(B2)^4)*(5-(t^2)+(9*(eta^2))+(4*(eta^4))))/24;
a5 = (N*(cos(B2)^5)*(5-(18*(t^2))+(t^4)+(14*(eta^2))-(58*(t^2)*(eta^2))))/120;
a6 = (t*N*(cos(B2)^6)*(61-(58*(t^2))+(t^4)+(270*(eta^2))-(330*(t^2)*(eta^2))))/720;
a7 = (N*(cos(B2)^7)*(61-(479*(t^2))+(179*(t^4))-(t^6)))/5040;
a8 = (t*N*(cos(B2)^8)*(1385-(3111*(t^2))+(543*(t^4))-(t^6)))/40320;

%Faktisk utregning til GCP:
N = B_arc + (a2*(l^2)) + (a4*(l^4)) + (a6*(l^6)) + (a8*(l^8)); 
E = (a1*l) + (a3*(l^3)) + (a5*(l^5)) + (a7*(l^7));

%Til UTM
UTM_N = N*0.9996;
UTM_E = (E*0.9996)+500000;

end

