function [ B, L ] = calculate_UTM2LatLon( UTM_N,UTM_E )
%Beregner fra UTM til geodetisk
%UTM-ellipsoiden:
a = 6378137;
b = 6356752.3142;

%m ha koordinatene i GCP, og ikke UTM (m korrigere mlestokk og offset)
GCP_N = UTM_N/0.9996; %HUSK: m dele p UTM-mlestokken, ikke gange med 1.0004!! (/0.9996)
GCP_E = (UTM_E-500000)/0.9996;

%Utregning av bredden i fotpunktet:
n = (a-b)/(a+b);
%alfa = 6367449.1458; %avhenger av ellipsekonstantene
alfa = ((a+b)/2)*(1+((1/4)*(n^2))+((1/64)*(n^4)));
beta = ((3/2)*n) - ((27/32)*(n^3)) + ((269/512)*(n^5));
gamma = ((21/16)*(n^2)) - ((55/32)*(n^4));
delta_spherical = ((151/96)*(n^3)) - ((417/128)*(n^5));
epsilon = ((1097/512)*(n^4));
N_GNSS = GCP_N/alfa; %N-verdier som benyttes i utregningene

%Fotpunktsbredden
B_f = N_GNSS + (beta*sin(2*N_GNSS)) + (gamma*sin(4*N_GNSS)) + (delta_spherical*sin(6*N_GNSS)) + (epsilon*sin(8*N_GNSS));
B_f_deg = rad2deg(B_f);

%ellipseegenskaper som trengs i videre utregninger
e_marked_squared = ((a^2)-(b^2))/(b^2);
eta_f_squared = e_marked_squared * (cos(B_f)^2);
N_f = (a^2)/(b*sqrt(1+(eta_f_squared)));
t_f = tan(B_f);

%Utregning av bredde- og lengdekoordinatene:
L_0 = 9; %sentralmeridianen i grader
L_0 = deg2rad(L_0); %i radianer

%Koeffisienter i den endelige formelen:
b1 = 1/(N_f*cos(B_f));
b2 = (t_f/(2*(N_f^2)))*(-1-eta_f_squared);
b3 = ((-1-(2*(t_f^2))-(eta_f_squared)))/((6*(N_f^3))*cos(B_f));
b4 = (t_f/(24*(N_f^4)))*(5+(3*(t_f^2))+(6*eta_f_squared)-(6*(t_f^2)*eta_f_squared)-(3*(eta_f_squared^2))-(9*(t_f^2)*(eta_f_squared^2)));
b5 = ((5+(28*(t_f^2))+(24*(t_f^4))+(6*eta_f_squared)+(8*(t_f^2)*eta_f_squared)))/(120*(N_f^5)*cos(B_f));
b6 = (t_f/(720*(N_f^6)))*(-61-(90*(t_f^2))-(45*(t_f^4))-(107*eta_f_squared)+(162*(t_f^2)*eta_f_squared)+(45*(t_f^4)*(eta_f_squared)));
b7 = ((-61-(662*(t_f^2))-(1320*(t_f^4))-(720*(t_f^6))))/(5040*(N_f^7)*cos(B_f));
b8 = (t_f/(40320*(N_f^8)))*(1385+(3633*(t_f^2))+(4095*(t_f^4))+(1575*(t_f^6)));

%Utregningen:
B = B_f + (b2*(GCP_E^2)) + (b4*(GCP_E^4)) + (b6*(GCP_E^6)) + (b8*(GCP_E^8));
B = rad2deg(B); %endelig koordinat
L = L_0 + (b1*GCP_E) + (b3*(GCP_E^3)) + (b5*(GCP_E^5)) + (b7*(GCP_E^7));
L = rad2deg(L); %endelig koordinat
end

